==> autofill-forms_1.0.2.orig.tar.xz: defaults/preferences/autofillForms.js <==
pref('extensions.autofillForms@blueimp.net.description', 'chrome://autofillForms/locale/autofillForms.properties');
pref('extensions.autofillForms@blueimp.net.shortcut', 'chrome://autofillForms/locale/autofillForms.properties');
pref('extensions.autofillForms@blueimp.net.shortcutSubmit', 'chrome://autofillForms/locale/autofillForms.properties');
pref('extensions.autofillForms@blueimp.net.shortcutAllTabs', 'chrome://autofillForms/locale/autofillForms.properties');
pref('extensions.autofillForms@blueimp.net.shortcutFromProfileSelection', 'chrome://autofillForms/locale/autofillForms.properties');
pref('extensions.autofillForms@blueimp.net.shortcutProfile', 'chrome://autofillForms/locale/autofillForms.properties');
pref('extensions.autofillForms@blueimp.net.shortcutSettings', 'chrome://autofillForms/locale/autofillForms.properties');
pref('extensions.autofillForms@blueimp.net.shortcutDisplayFormDetails', 'chrome://autofillForms/locale/autofillForms.properties');
pref('extensions.autofillForms@blueimp.net.mouseShortcut', 'mousebutton0');
pref('extensions.autofillForms@blueimp.net.mouseShortcutSubmit', 'control+mousebutton0');
pref('extensions.autofillForms@blueimp.net.mouseShortcutAllTabs', 'control+mousebutton1');
pref('extensions.autofillForms@blueimp.net.mouseShortcutFromProfileSelection', 'mousebutton1');
pref('extensions.autofillForms@blueimp.net.mouseShortcutProfile', '');
pref('extensions.autofillForms@blueimp.net.mouseShortcutSettings', '');
pref('extensions.autofillForms@blueimp.net.mouseShortcutDisplayFormDetails', '');
pref('extensions.autofillForms@blueimp.net.fieldRules', 'chrome://autofillForms/locale/autofillForms.properties');
pref('extensions.autofillForms@blueimp.net.profileLabels', 'chrome://autofillForms/locale/autofillForms.properties');
pref('extensions.autofillForms@blueimp.net.dynamicTags', 'chrome://autofillForms/locale/autofillForms.properties');
pref('extensions.autofillForms@blueimp.net.dynamicTagCodes', 'chrome://autofillForms/locale/autofillForms.properties');
pref('extensions.autofillForms@blueimp.net.regExpPasswordLabel', 'chrome://autofillForms/locale/autofillForms.properties');
pref('extensions.autofillForms@blueimp.net.regExpFormFieldTypes', '^(?:(?:text(?:area)?)|(?:select-(?:(?:one)|(?:multiple)))|(?:checkbox)|(?:radio)|(?:email)|(?:url)|(?:password)|(?:file))$');
pref('extensions.autofillForms@blueimp.net.enableDynamicTags', false);
pref('extensions.autofillForms@blueimp.net.profileIndex', 0);
pref('extensions.autofillForms@blueimp.net.storeEncrypted', false);
pref('extensions.autofillForms@blueimp.net.formDetailsStyle', 'color:#000; background-color:#FFFF00; border:1px solid #000;');
pref('extensions.autofillForms@blueimp.net.rememberAlternativesIndex', true);
pref('extensions.autofillForms@blueimp.net.placeholderLineBreak', '<br>');
pref('extensions.autofillForms@blueimp.net.placeholderTab', '    ');
pref('extensions.autofillForms@blueimp.net.highlightStyleMatch', '');
pref('extensions.autofillForms@blueimp.net.highlightStyleNoMatch', '');
pref('extensions.autofillForms@blueimp.net.enableGlobalProfile', false);
pref('extensions.autofillForms@blueimp.net.globalProfileIndex', 0);
pref('extensions.autofillForms@blueimp.net.formFieldsContextMenuProfileIndex', -3);
pref('extensions.autofillForms@blueimp.net.ignoreDisabledRulesOnAutofill', true);
pref('extensions.autofillForms@blueimp.net.ignoreDisabledFields', true);
pref('extensions.autofillForms@blueimp.net.disableAlternatives', false);
pref('extensions.autofillForms@blueimp.net.callOnChangeAfterFillingFields', false);
pref('extensions.autofillForms@blueimp.net.enableConfirmationDialogs', true);
pref('extensions.autofillForms@blueimp.net.matchAgainstLabels', true);
pref('extensions.autofillForms@blueimp.net.labelsStrictMode', true);
pref('extensions.autofillForms@blueimp.net.matchAgainstPositions', false);
pref('extensions.autofillForms@blueimp.net.positionsIdentifier', '#');
pref('extensions.autofillForms@blueimp.net.focusLastFormElementMatch', true);
pref('extensions.autofillForms@blueimp.net.hideStatusbarIcon', true);
pref('extensions.autofillForms@blueimp.net.hideContextMenuItem', false);
pref('extensions.autofillForms@blueimp.net.hideFormFieldsContextMenu', false);
pref('extensions.autofillForms@blueimp.net.hideToolbarButton', false);
pref('extensions.autofillForms@blueimp.net.hideToolbarButtonMenu', false);
pref('extensions.autofillForms@blueimp.net.configDirectory', '');
pref('extensions.autofillForms@blueimp.net.useConfigDirectory', false);
pref('extensions.autofillForms@blueimp.net.profileSiteRules', '(?:)');
pref('extensions.autofillForms@blueimp.net.autoSelectBestProfile', true);
pref('extensions.autofillForms@blueimp.net.helpURL', 'http://firefox.add0n.com/autofill-forms.html');
pref("extensions.autofillForms@blueimp.net.just_installed", true);
pref("extensions.autofillForms@blueimp.net.post_install_url", "http://firefox.add0n.com/autofill-forms.html");

==> autofill-forms_1.1.3.orig.tar.xz: defaults/preferences/autofillForms.js <==
pref('extensions.autofillForms@blueimp.net.description', 'chrome://autofillForms/locale/autofillForms.properties');
pref('extensions.autofillForms@blueimp.net.shortcut', 'chrome://autofillForms/locale/autofillForms.properties');
pref('extensions.autofillForms@blueimp.net.shortcutSubmit', 'chrome://autofillForms/locale/autofillForms.properties');
pref('extensions.autofillForms@blueimp.net.shortcutAllTabs', 'chrome://autofillForms/locale/autofillForms.properties');
pref('extensions.autofillForms@blueimp.net.shortcutFromProfileSelection', 'chrome://autofillForms/locale/autofillForms.properties');
pref('extensions.autofillForms@blueimp.net.shortcutProfile', 'chrome://autofillForms/locale/autofillForms.properties');
pref('extensions.autofillForms@blueimp.net.shortcutSettings', 'chrome://autofillForms/locale/autofillForms.properties');
pref('extensions.autofillForms@blueimp.net.shortcutDisplayFormDetails', 'chrome://autofillForms/locale/autofillForms.properties');
pref('extensions.autofillForms@blueimp.net.mouseShortcut', 'mousebutton0');
pref('extensions.autofillForms@blueimp.net.mouseShortcutSubmit', 'control+mousebutton0');
pref('extensions.autofillForms@blueimp.net.mouseShortcutAllTabs', 'control+mousebutton1');
pref('extensions.autofillForms@blueimp.net.mouseShortcutFromProfileSelection', 'mousebutton1');
pref('extensions.autofillForms@blueimp.net.mouseShortcutProfile', '');
pref('extensions.autofillForms@blueimp.net.mouseShortcutSettings', '');
pref('extensions.autofillForms@blueimp.net.mouseShortcutDisplayFormDetails', '');
pref('extensions.autofillForms@blueimp.net.fieldRules', 'chrome://autofillForms/locale/autofillForms.properties');
pref('extensions.autofillForms@blueimp.net.profileLabels', 'chrome://autofillForms/locale/autofillForms.properties');
pref('extensions.autofillForms@blueimp.net.dynamicTags', 'chrome://autofillForms/locale/autofillForms.properties');
pref('extensions.autofillForms@blueimp.net.dynamicTagCodes', 'chrome://autofillForms/locale/autofillForms.properties');
pref('extensions.autofillForms@blueimp.net.regExpPasswordLabel', 'chrome://autofillForms/locale/autofillForms.properties');
pref('extensions.autofillForms@blueimp.net.regExpFormFieldTypes', '^(?:(?:text(?:area)?)|(?:select-(?:(?:one)|(?:multiple)))|(?:checkbox)|(?:radio)|(?:email)|(?:url)|(?:number)|(?:month)|(?:week)|(?:tel)|(?:password)|(?:file))$');
pref('extensions.autofillForms@blueimp.net.enableDynamicTags', false);
pref('extensions.autofillForms@blueimp.net.profileIndex', 0);
pref('extensions.autofillForms@blueimp.net.storeEncrypted', false);
pref('extensions.autofillForms@blueimp.net.formDetailsStyle', 'color:#000; background-color:#FFFF00; border:1px solid #000;');
pref('extensions.autofillForms@blueimp.net.rememberAlternativesIndex', true);
pref('extensions.autofillForms@blueimp.net.placeholderLineBreak', '<br>');
pref('extensions.autofillForms@blueimp.net.placeholderTab', '    ');
pref('extensions.autofillForms@blueimp.net.highlightStyleMatch', '');
pref('extensions.autofillForms@blueimp.net.highlightStyleNoMatch', '');
pref('extensions.autofillForms@blueimp.net.enableGlobalProfile', false);
pref('extensions.autofillForms@blueimp.net.globalProfileIndex', 0);
pref('extensions.autofillForms@blueimp.net.formFieldsContextMenuProfileIndex', -3);
pref('extensions.autofillForms@blueimp.net.ignoreDisabledRulesOnAutofill', true);
pref('extensions.autofillForms@blueimp.net.ignoreDisabledFields', true);
pref('extensions.autofillForms@blueimp.net.disableAlternatives', false);
pref('extensions.autofillForms@blueimp.net.callOnChangeAfterFillingFields', false);
pref('extensions.autofillForms@blueimp.net.enableConfirmationDialogs', true);
pref('extensions.autofillForms@blueimp.net.matchAgainstLabels', true);
pref('extensions.autofillForms@blueimp.net.labelsStrictMode', true);
pref('extensions.autofillForms@blueimp.net.matchAgainstPositions', false);
pref('extensions.autofillForms@blueimp.net.positionsIdentifier', '#');
pref('extensions.autofillForms@blueimp.net.focusLastFormElementMatch', true);
pref('extensions.autofillForms@blueimp.net.hideStatusbarIcon', true);
pref('extensions.autofillForms@blueimp.net.hideContextMenuItem', false);
pref('extensions.autofillForms@blueimp.net.hideFormFieldsContextMenu', false);
pref('extensions.autofillForms@blueimp.net.hideToolbarButton', false);
pref('extensions.autofillForms@blueimp.net.hideToolbarButtonMenu', false);
pref('extensions.autofillForms@blueimp.net.configDirectory', '');
pref('extensions.autofillForms@blueimp.net.useConfigDirectory', false);
pref('extensions.autofillForms@blueimp.net.profileSiteRules', '(?:)');
pref('extensions.autofillForms@blueimp.net.autoSelectBestProfile', true);
pref('extensions.autofillForms@blueimp.net.helpURL', 'http://firefox.add0n.com/autofill-forms.html');
pref("extensions.autofillForms@blueimp.net.welcome", true);
pref("extensions.autofillForms@blueimp.net.version", "");
pref("extensions.autofillForms@blueimp.net.post_install_url", "http://firefox.add0n.com/autofill-forms.html");
